fastapi\_contrib.auth package
=============================

Submodules
----------

fastapi\_contrib.auth.backends module
-------------------------------------

.. automodule:: fastapi_contrib.auth.backends
    :members:
    :undoc-members:
    :show-inheritance:

fastapi\_contrib.auth.middlewares module
----------------------------------------

.. automodule:: fastapi_contrib.auth.middlewares
    :members:
    :undoc-members:
    :show-inheritance:

fastapi\_contrib.auth.models module
-----------------------------------

.. automodule:: fastapi_contrib.auth.models
    :members:
    :undoc-members:
    :show-inheritance:

fastapi\_contrib.auth.permissions module
----------------------------------------

.. automodule:: fastapi_contrib.auth.permissions
    :members:
    :undoc-members:
    :show-inheritance:

fastapi\_contrib.auth.serializers module
----------------------------------------

.. automodule:: fastapi_contrib.auth.serializers
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: fastapi_contrib.auth
    :members:
    :undoc-members:
    :show-inheritance:
